==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/AzureFirewallNatRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.AzureFirewallNatRuleArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.AzureFirewallNetworkRuleProtocol
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a NAT rule.
 * @property description Description of the rule.
 * @property destinationAddresses List of destination IP addresses for this rule. Supports IP ranges, prefixes, and service tags.
 * @property destinationPorts List of destination ports.
 * @property name Name of the NAT rule.
 * @property protocols Array of AzureFirewallNetworkRuleProtocols applicable to this NAT rule.
 * @property sourceAddresses List of source IP addresses for this rule.
 * @property sourceIpGroups List of source IpGroups for this rule.
 * @property translatedAddress The translated address for this NAT rule.
 * @property translatedFqdn The translated FQDN for this NAT rule.
 * @property translatedPort The translated port for this NAT rule.
 */
public data class AzureFirewallNatRuleArgs(
    public val description: Output<String>? = null,
    public val destinationAddresses: Output<List<String>>? = null,
    public val destinationPorts: Output<List<String>>? = null,
    public val name: Output<String>? = null,
    public val protocols: Output<List<Either<String, AzureFirewallNetworkRuleProtocol>>>? = null,
    public val sourceAddresses: Output<List<String>>? = null,
    public val sourceIpGroups: Output<List<String>>? = null,
    public val translatedAddress: Output<String>? = null,
    public val translatedFqdn: Output<String>? = null,
    public val translatedPort: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.AzureFirewallNatRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.AzureFirewallNatRuleArgs =
        com.pulumi.azurenative.network.inputs.AzureFirewallNatRuleArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .destinationAddresses(destinationAddresses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .destinationPorts(destinationPorts?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .protocols(
                protocols?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform(
                            { args0 -> args0 },
                            { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        )
                    })
                }),
            )
            .sourceAddresses(sourceAddresses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .sourceIpGroups(sourceIpGroups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .translatedAddress(translatedAddress?.applyValue({ args0 -> args0 }))
            .translatedFqdn(translatedFqdn?.applyValue({ args0 -> args0 }))
            .translatedPort(translatedPort?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureFirewallNatRuleArgs].
 */
@PulumiTagMarker
public class AzureFirewallNatRuleArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var destinationAddresses: Output<List<String>>? = null

    private var destinationPorts: Output<List<String>>? = null

    private var name: Output<String>? = null

    private var protocols: Output<List<Either<String, AzureFirewallNetworkRuleProtocol>>>? = null

    private var sourceAddresses: Output<List<String>>? = null

    private var sourceIpGroups: Output<List<String>>? = null

    private var translatedAddress: Output<String>? = null

    private var translatedFqdn: Output<String>? = null

    private var translatedPort: Output<String>? = null

    /**
     * @param value Description of the rule.
     */
    @JvmName("wnnlnkkynccrjgic")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value List of destination IP addresses for this rule. Supports IP ranges, prefixes, and service tags.
     */
    @JvmName("ntevaftshxkqcxco")
    public suspend fun destinationAddresses(`value`: Output<List<String>>) {
        this.destinationAddresses = value
    }

    @JvmName("jgsebiltnmmrikbm")
    public suspend fun destinationAddresses(vararg values: Output<String>) {
        this.destinationAddresses = Output.all(values.asList())
    }

    /**
     * @param values List of destination IP addresses for this rule. Supports IP ranges, prefixes, and service tags.
     */
    @JvmName("mncmsqhevquggttk")
    public suspend fun destinationAddresses(values: List<Output<String>>) {
        this.destinationAddresses = Output.all(values)
    }

    /**
     * @param value List of destination ports.
     */
    @JvmName("cdsinvpacojtmvlv")
    public suspend fun destinationPorts(`value`: Output<List<String>>) {
        this.destinationPorts = value
    }

    @JvmName("uddoqamplkaoowhc")
    public suspend fun destinationPorts(vararg values: Output<String>) {
        this.destinationPorts = Output.all(values.asList())
    }

    /**
     * @param values List of destination ports.
     */
    @JvmName("bqgxeqfswphmowul")
    public suspend fun destinationPorts(values: List<Output<String>>) {
        this.destinationPorts = Output.all(values)
    }

    /**
     * @param value Name of the NAT rule.
     */
    @JvmName("dbtuhrjhhriaoobt")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Array of AzureFirewallNetworkRuleProtocols applicable to this NAT rule.
     */
    @JvmName("lgsboyfsjvsbpaoj")
    public suspend
    fun protocols(`value`: Output<List<Either<String, AzureFirewallNetworkRuleProtocol>>>) {
        this.protocols = value
    }

    @JvmName("tsuglfilrfsfpvuw")
    public suspend fun protocols(
        vararg
        values: Output<Either<String, AzureFirewallNetworkRuleProtocol>>,
    ) {
        this.protocols = Output.all(values.asList())
    }

    /**
     * @param values Array of AzureFirewallNetworkRuleProtocols applicable to this NAT rule.
     */
    @JvmName("jwbjiabcvyfydcyo")
    public suspend
    fun protocols(values: List<Output<Either<String, AzureFirewallNetworkRuleProtocol>>>) {
        this.protocols = Output.all(values)
    }

    /**
     * @param value List of source IP addresses for this rule.
     */
    @JvmName("estcbiswchddwiyb")
    public suspend fun sourceAddresses(`value`: Output<List<String>>) {
        this.sourceAddresses = value
    }

    @JvmName("moqtmhabbnixpixq")
    public suspend fun sourceAddresses(vararg values: Output<String>) {
        this.sourceAddresses = Output.all(values.asList())
    }

    /**
     * @param values List of source IP addresses for this rule.
     */
    @JvmName("xxmrbgmfnehflvpa")
    public suspend fun sourceAddresses(values: List<Output<String>>) {
        this.sourceAddresses = Output.all(values)
    }

    /**
     * @param value List of source IpGroups for this rule.
     */
    @JvmName("sxwmanushcanimxu")
    public suspend fun sourceIpGroups(`value`: Output<List<String>>) {
        this.sourceIpGroups = value
    }

    @JvmName("acgsyimwrfjyvorw")
    public suspend fun sourceIpGroups(vararg values: Output<String>) {
        this.sourceIpGroups = Output.all(values.asList())
    }

    /**
     * @param values List of source IpGroups for this rule.
     */
    @JvmName("cirpgrllvukfkens")
    public suspend fun sourceIpGroups(values: List<Output<String>>) {
        this.sourceIpGroups = Output.all(values)
    }

    /**
     * @param value The translated address for this NAT rule.
     */
    @JvmName("rucvwihaebdyfnfd")
    public suspend fun translatedAddress(`value`: Output<String>) {
        this.translatedAddress = value
    }

    /**
     * @param value The translated FQDN for this NAT rule.
     */
    @JvmName("bkrridskyaconean")
    public suspend fun translatedFqdn(`value`: Output<String>) {
        this.translatedFqdn = value
    }

    /**
     * @param value The translated port for this NAT rule.
     */
    @JvmName("njcawhlebhikkeqj")
    public suspend fun translatedPort(`value`: Output<String>) {
        this.translatedPort = value
    }

    /**
     * @param value Description of the rule.
     */
    @JvmName("hqdegtkitqpgyubo")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value List of destination IP addresses for this rule. Supports IP ranges, prefixes, and service tags.
     */
    @JvmName("vurqbepoykgclekb")
    public suspend fun destinationAddresses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationAddresses = mapped
    }

    /**
     * @param values List of destination IP addresses for this rule. Supports IP ranges, prefixes, and service tags.
     */
    @JvmName("bbwyhosnjcgpahfs")
    public suspend fun destinationAddresses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.destinationAddresses = mapped
    }

    /**
     * @param value List of destination ports.
     */
    @JvmName("ckomssoisiecvybr")
    public suspend fun destinationPorts(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationPorts = mapped
    }

    /**
     * @param values List of destination ports.
     */
    @JvmName("upkbkinxqvncwtoy")
    public suspend fun destinationPorts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.destinationPorts = mapped
    }

    /**
     * @param value Name of the NAT rule.
     */
    @JvmName("dotabdlhybtelexk")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Array of AzureFirewallNetworkRuleProtocols applicable to this NAT rule.
     */
    @JvmName("jonpsmvxvcqmagxa")
    public suspend fun protocols(`value`: List<Either<String, AzureFirewallNetworkRuleProtocol>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocols = mapped
    }

    /**
     * @param values Array of AzureFirewallNetworkRuleProtocols applicable to this NAT rule.
     */
    @JvmName("imxoawsdhgbrahrr")
    public suspend fun protocols(vararg values: Either<String, AzureFirewallNetworkRuleProtocol>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocols = mapped
    }

    /**
     * @param value List of source IP addresses for this rule.
     */
    @JvmName("dscvtcvakmbrwsud")
    public suspend fun sourceAddresses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceAddresses = mapped
    }

    /**
     * @param values List of source IP addresses for this rule.
     */
    @JvmName("tlsikullwsahfrgc")
    public suspend fun sourceAddresses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceAddresses = mapped
    }

    /**
     * @param value List of source IpGroups for this rule.
     */
    @JvmName("cqpqmjdrgaakyqsg")
    public suspend fun sourceIpGroups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceIpGroups = mapped
    }

    /**
     * @param values List of source IpGroups for this rule.
     */
    @JvmName("ffoyqbvrbtglfkkg")
    public suspend fun sourceIpGroups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceIpGroups = mapped
    }

    /**
     * @param value The translated address for this NAT rule.
     */
    @JvmName("lwovcjnfxlxgcnme")
    public suspend fun translatedAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.translatedAddress = mapped
    }

    /**
     * @param value The translated FQDN for this NAT rule.
     */
    @JvmName("svgocfigygoxxarl")
    public suspend fun translatedFqdn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.translatedFqdn = mapped
    }

    /**
     * @param value The translated port for this NAT rule.
     */
    @JvmName("nbxbafkmnmjubevl")
    public suspend fun translatedPort(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.translatedPort = mapped
    }

    internal fun build(): AzureFirewallNatRuleArgs = AzureFirewallNatRuleArgs(
        description = description,
        destinationAddresses = destinationAddresses,
        destinationPorts = destinationPorts,
        name = name,
        protocols = protocols,
        sourceAddresses = sourceAddresses,
        sourceIpGroups = sourceIpGroups,
        translatedAddress = translatedAddress,
        translatedFqdn = translatedFqdn,
        translatedPort = translatedPort,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/AzureFirewallNatRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.AzureFirewallNatRuleArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.AzureFirewallNetworkRuleProtocol
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a NAT rule.
 * @property description Description of the rule.
 * @property destinationAddresses List of destination IP addresses for this rule. Supports IP ranges, prefixes, and service tags.
 * @property destinationPorts List of destination ports.
 * @property name Name of the NAT rule.
 * @property protocols Array of AzureFirewallNetworkRuleProtocols applicable to this NAT rule.
 * @property sourceAddresses List of source IP addresses for this rule.
 * @property sourceIpGroups List of source IpGroups for this rule.
 * @property translatedAddress The translated address for this NAT rule.
 * @property translatedFqdn The translated FQDN for this NAT rule.
 * @property translatedPort The translated port for this NAT rule.
 */
public data class AzureFirewallNatRuleArgs(
    public val description: Output<String>? = null,
    public val destinationAddresses: Output<List<String>>? = null,
    public val destinationPorts: Output<List<String>>? = null,
    public val name: Output<String>? = null,
    public val protocols: Output<List<Either<String, AzureFirewallNetworkRuleProtocol>>>? = null,
    public val sourceAddresses: Output<List<String>>? = null,
    public val sourceIpGroups: Output<List<String>>? = null,
    public val translatedAddress: Output<String>? = null,
    public val translatedFqdn: Output<String>? = null,
    public val translatedPort: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.AzureFirewallNatRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.AzureFirewallNatRuleArgs =
        com.pulumi.azurenative.network.inputs.AzureFirewallNatRuleArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .destinationAddresses(destinationAddresses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .destinationPorts(destinationPorts?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .protocols(
                protocols?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform(
                            { args0 -> args0 },
                            { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        )
                    })
                }),
            )
            .sourceAddresses(sourceAddresses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .sourceIpGroups(sourceIpGroups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .translatedAddress(translatedAddress?.applyValue({ args0 -> args0 }))
            .translatedFqdn(translatedFqdn?.applyValue({ args0 -> args0 }))
            .translatedPort(translatedPort?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureFirewallNatRuleArgs].
 */
@PulumiTagMarker
public class AzureFirewallNatRuleArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var destinationAddresses: Output<List<String>>? = null

    private var destinationPorts: Output<List<String>>? = null

    private var name: Output<String>? = null

    private var protocols: Output<List<Either<String, AzureFirewallNetworkRuleProtocol>>>? = null

    private var sourceAddresses: Output<List<String>>? = null

    private var sourceIpGroups: Output<List<String>>? = null

    private var translatedAddress: Output<String>? = null

    private var translatedFqdn: Output<String>? = null

    private var translatedPort: Output<String>? = null

    /**
     * @param value Description of the rule.
     */
    @JvmName("sgqtlpqhlchylmtk")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value List of destination IP addresses for this rule. Supports IP ranges, prefixes, and service tags.
     */
    @JvmName("wylmpwuudhtoblxb")
    public suspend fun destinationAddresses(`value`: Output<List<String>>) {
        this.destinationAddresses = value
    }

    @JvmName("vlchdfsabawaqevj")
    public suspend fun destinationAddresses(vararg values: Output<String>) {
        this.destinationAddresses = Output.all(values.asList())
    }

    /**
     * @param values List of destination IP addresses for this rule. Supports IP ranges, prefixes, and service tags.
     */
    @JvmName("oqhdgskxtxxjensl")
    public suspend fun destinationAddresses(values: List<Output<String>>) {
        this.destinationAddresses = Output.all(values)
    }

    /**
     * @param value List of destination ports.
     */
    @JvmName("csipnsydjpkgyvjx")
    public suspend fun destinationPorts(`value`: Output<List<String>>) {
        this.destinationPorts = value
    }

    @JvmName("kcqrygvrofaduqqw")
    public suspend fun destinationPorts(vararg values: Output<String>) {
        this.destinationPorts = Output.all(values.asList())
    }

    /**
     * @param values List of destination ports.
     */
    @JvmName("neehlpnxbrsvmjmx")
    public suspend fun destinationPorts(values: List<Output<String>>) {
        this.destinationPorts = Output.all(values)
    }

    /**
     * @param value Name of the NAT rule.
     */
    @JvmName("ljiclwnjiusopanu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Array of AzureFirewallNetworkRuleProtocols applicable to this NAT rule.
     */
    @JvmName("ycxalvqyvwnddxky")
    public suspend
    fun protocols(`value`: Output<List<Either<String, AzureFirewallNetworkRuleProtocol>>>) {
        this.protocols = value
    }

    @JvmName("iyomdwdxqmskapoe")
    public suspend fun protocols(
        vararg
        values: Output<Either<String, AzureFirewallNetworkRuleProtocol>>,
    ) {
        this.protocols = Output.all(values.asList())
    }

    /**
     * @param values Array of AzureFirewallNetworkRuleProtocols applicable to this NAT rule.
     */
    @JvmName("svwvnrtuurwpvtwk")
    public suspend
    fun protocols(values: List<Output<Either<String, AzureFirewallNetworkRuleProtocol>>>) {
        this.protocols = Output.all(values)
    }

    /**
     * @param value List of source IP addresses for this rule.
     */
    @JvmName("exbkuinqkqmhxesg")
    public suspend fun sourceAddresses(`value`: Output<List<String>>) {
        this.sourceAddresses = value
    }

    @JvmName("cktkgpidehspmxte")
    public suspend fun sourceAddresses(vararg values: Output<String>) {
        this.sourceAddresses = Output.all(values.asList())
    }

    /**
     * @param values List of source IP addresses for this rule.
     */
    @JvmName("xvlkqpucfsaflunj")
    public suspend fun sourceAddresses(values: List<Output<String>>) {
        this.sourceAddresses = Output.all(values)
    }

    /**
     * @param value List of source IpGroups for this rule.
     */
    @JvmName("jvclytrxptygflci")
    public suspend fun sourceIpGroups(`value`: Output<List<String>>) {
        this.sourceIpGroups = value
    }

    @JvmName("aixeulshvlbxrbom")
    public suspend fun sourceIpGroups(vararg values: Output<String>) {
        this.sourceIpGroups = Output.all(values.asList())
    }

    /**
     * @param values List of source IpGroups for this rule.
     */
    @JvmName("hhfgeodbtahgkbbo")
    public suspend fun sourceIpGroups(values: List<Output<String>>) {
        this.sourceIpGroups = Output.all(values)
    }

    /**
     * @param value The translated address for this NAT rule.
     */
    @JvmName("omuynpnuvlrrjcrp")
    public suspend fun translatedAddress(`value`: Output<String>) {
        this.translatedAddress = value
    }

    /**
     * @param value The translated FQDN for this NAT rule.
     */
    @JvmName("jowusmutkgfrdwvv")
    public suspend fun translatedFqdn(`value`: Output<String>) {
        this.translatedFqdn = value
    }

    /**
     * @param value The translated port for this NAT rule.
     */
    @JvmName("dplhxhrbgcwtalqr")
    public suspend fun translatedPort(`value`: Output<String>) {
        this.translatedPort = value
    }

    /**
     * @param value Description of the rule.
     */
    @JvmName("ftkmqktcfimvxpay")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value List of destination IP addresses for this rule. Supports IP ranges, prefixes, and service tags.
     */
    @JvmName("qfakmlmvclhsgshl")
    public suspend fun destinationAddresses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationAddresses = mapped
    }

    /**
     * @param values List of destination IP addresses for this rule. Supports IP ranges, prefixes, and service tags.
     */
    @JvmName("wrslqpgrhbwauohk")
    public suspend fun destinationAddresses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.destinationAddresses = mapped
    }

    /**
     * @param value List of destination ports.
     */
    @JvmName("htrkwvvbkmjytpdq")
    public suspend fun destinationPorts(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationPorts = mapped
    }

    /**
     * @param values List of destination ports.
     */
    @JvmName("hmgvjfgidwjbljyp")
    public suspend fun destinationPorts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.destinationPorts = mapped
    }

    /**
     * @param value Name of the NAT rule.
     */
    @JvmName("qpgaqiqagxslayed")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Array of AzureFirewallNetworkRuleProtocols applicable to this NAT rule.
     */
    @JvmName("oafjakmcxipekwsi")
    public suspend fun protocols(`value`: List<Either<String, AzureFirewallNetworkRuleProtocol>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocols = mapped
    }

    /**
     * @param values Array of AzureFirewallNetworkRuleProtocols applicable to this NAT rule.
     */
    @JvmName("vtshwuimugncxnyb")
    public suspend fun protocols(vararg values: Either<String, AzureFirewallNetworkRuleProtocol>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocols = mapped
    }

    /**
     * @param value List of source IP addresses for this rule.
     */
    @JvmName("drhteniyyiletkdv")
    public suspend fun sourceAddresses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceAddresses = mapped
    }

    /**
     * @param values List of source IP addresses for this rule.
     */
    @JvmName("lntcqcbskaalhulu")
    public suspend fun sourceAddresses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceAddresses = mapped
    }

    /**
     * @param value List of source IpGroups for this rule.
     */
    @JvmName("hdiyiixapaksdbdq")
    public suspend fun sourceIpGroups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceIpGroups = mapped
    }

    /**
     * @param values List of source IpGroups for this rule.
     */
    @JvmName("xojtmgvdqfbakbie")
    public suspend fun sourceIpGroups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceIpGroups = mapped
    }

    /**
     * @param value The translated address for this NAT rule.
     */
    @JvmName("uiwwrainpxsfpbdf")
    public suspend fun translatedAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.translatedAddress = mapped
    }

    /**
     * @param value The translated FQDN for this NAT rule.
     */
    @JvmName("lpffobbdqmdsqpcn")
    public suspend fun translatedFqdn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.translatedFqdn = mapped
    }

    /**
     * @param value The translated port for this NAT rule.
     */
    @JvmName("bqbvjlqukbaxtrts")
    public suspend fun translatedPort(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.translatedPort = mapped
    }

    internal fun build(): AzureFirewallNatRuleArgs = AzureFirewallNatRuleArgs(
        description = description,
        destinationAddresses = destinationAddresses,
        destinationPorts = destinationPorts,
        name = name,
        protocols = protocols,
        sourceAddresses = sourceAddresses,
        sourceIpGroups = sourceIpGroups,
        translatedAddress = translatedAddress,
        translatedFqdn = translatedFqdn,
        translatedPort = translatedPort,
    )
}
